==> cv-library-react-web-0.1.6.tgz: package/src/components/LauncherList/LauncherList.js <==
import React from 'react';
import PropTypes from 'prop-types';

import LauncherItem from '../LauncherItem/LauncherItem';

import getStyles from './LauncherList.styles';

/**
 * A listing of workbench action launchers
 */
const LauncherList = (props) => {
    const {
        gridView,
        launchers,
        onLauncherClick,
        contextStyles,
        testID,
    } = props;

    const styles = getStyles(contextStyles);

    // Generate container props
    const containerProps = {
        style: styles.container,
    };

    // TODO: do the mobile equivalent
    if (gridView) { /** */ }
    if (testID) { containerProps['test-id'] = `${testID}__container`; }

    return (
        <div { ...containerProps }>
            { launchers.map((launcher) => {
                const {
                    iconBase,
                    id,
                    name,
                } = launcher;

                // Generate launcher props
                const launcherProps = {
                    icon: iconBase,
                    contextStyles: {
                        container: styles.launcher,
                        icon: styles.launcherIcon,
                        text: styles.launcherText,
                    },
                    text: name,
                };
                if (onLauncherClick) { launcherProps.onClick = () => { onLauncherClick(launcher); }; }
                if (testID) { launcherProps['test-id'] = `${testID}__launcher`; }

                return (
                    <LauncherItem
                        key={ id }
                        { ...launcherProps } />
                );
            }) }
        </div>
    );
};

LauncherList.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styling for the main container */
        container: PropTypes.object,

        /** Styling for each launcher container */
        launcher: PropTypes.object,

        /** Styling for each launcher icon/image */
        launcherIcon: PropTypes.object,

        /** Styling for each launcher text */
        launcherText: PropTypes.object,
    }),

    /** */
    gridView: PropTypes.bool,

    /** */
    launchers: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.string,
        name: PropTypes.string,
        iconBase: PropTypes.string,
    })).isRequired,

    /** */
    onLauncherClick: PropTypes.func,

    /** Id used for testing */
    testID: PropTypes.string,
};

LauncherList.defaultProps = {
    contextStyles: {},
};

export default LauncherList;

==> cv-library-react-web-0.1.14.tgz: package/src/components/LauncherList/LauncherList.js <==
import React from 'react';
import PropTypes from 'prop-types';

import LauncherItem from '../LauncherItem/LauncherItem';

import getStyles from './LauncherList.styles';

/**
 * A listing of workbench action launchers
 */
const LauncherList = (props) => {
    const {
        gridView,
        launchers,
        onLauncherClick,
        contextStyles,
        testID,
    } = props;

    const styles = getStyles(contextStyles);

    // Generate container props
    const containerProps = {
        className: 'c-launcher-list__container',
        style: styles.container,
    };

    // TODO: do the mobile equivalent
    if (!gridView) { containerProps.style = {}; }
    if (testID) { containerProps['test-id'] = `${testID}__launcher-list__container`; }

    return (
        <div { ...containerProps }>
            { launchers.map((launcher) => {
                const {
                    iconBase,
                    id,
                    name,
                } = launcher;

                // Generate launcher props
                const launcherProps = {
                    className: 'c-launcher-list__launcher-item',
                    contextStyles: {
                        container: styles.launcher,
                        icon: styles.launcherIcon,
                        text: styles.launcherText,
                    },
                    icon: iconBase,
                    text: name,
                };
                if (onLauncherClick) { launcherProps.onClick = () => { onLauncherClick(launcher); }; }
                if (testID) { launcherProps.testID = `${testID}__launcher-list__launcher-item`; }

                return (
                    <LauncherItem
                        key={ id }
                        { ...launcherProps } />
                );
            }) }
        </div>
    );
};

LauncherList.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styling for the main container */
        container: PropTypes.object,

        /** Styling for each launcher container */
        launcher: PropTypes.object,

        /** Styling for each launcher icon/image */
        launcherIcon: PropTypes.object,

        /** Styling for each launcher text */
        launcherText: PropTypes.object,
    }),

    /** */
    gridView: PropTypes.bool,

    /** */
    launchers: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.string,
        name: PropTypes.string,
        iconBase: PropTypes.string,
    })).isRequired,

    /** */
    onLauncherClick: PropTypes.func,

    /** Id used for testing */
    testID: PropTypes.string,
};

LauncherList.defaultProps = {
    contextStyles: {},
    gridView: true,
};

export default LauncherList;
